@@ -22,6 +22,7 @@ import pwd
 import re
 import shutil
 import stat
+import struct
 import sys
 import time
 from distutils import spawn
@@ -52,7 +53,17 @@ DEFAULT_DOCKER_LOG='/var/lib/drydock/docker.log'
 
 class Installer(object):
 
+    """
+    Determine if this architecture is in fact 64-bit. 
+    """
+    def _supported_arch(self):
+        return struct.calcsize("P") * 8 == 64
+        
     def install(self, args):
+        # Check if the host is actually 64-bit. If not raise a warning and quit.
+        if not self._supported_arch():
+            return 'Your architecture appears to be 32-bit.\nOnly 64-bit architectures are supported at the moment.'
+
         self._start_docker_daemon()
 
         if '-k' in args:
@@ -73,6 +84,7 @@ class Installer(object):
                 self.build_from_list(to_build, 
                                      DEFAULT_IMAGE_DIR,
                                      DEFAULT_DOCKER_REPO)
+        return 'installed ferry'
 
     def start_web(self):
         self._start_docker_daemon()
@@ -123,7 +135,7 @@ class Installer(object):
         my_env = os.environ.copy()
         my_env['MONGODB'] = ip
         logging.warning("starting http servers on port 4000 and mongo %s" % ip)
-        cmd = 'gunicorn -e FERRY_HOME=%s -t 3600 -w 3 -k gevent -b 127.0.0.1:4000 ferry.http.httpapi:app &' % FERRY_HOME
+        cmd = 'gunicorn -e FERRY_HOME=%s -t 3600 -w 3 -b 127.0.0.1:4000 ferry.http.httpapi:app &' % FERRY_HOME
         Popen(cmd, stdout=PIPE, shell=True, env=my_env)
 
     def stop_web(self):
